==> form-dinamico-react-render-0.2.8.tgz: package/es/widgets/mui/TableEditableWidget.js <==
var _class, _temp, _initialiseProps;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';

import Paper from 'material-ui/Paper';
import { FormControl, FormGroup, FormLabel } from 'material-ui/Form';

import { EditingState } from '@devexpress/dx-react-grid';
import { Grid, Table, TableEditColumn, TableEditRow, TableHeaderRow } from '@devexpress/dx-react-grid-material-ui';

var getRowId = function getRowId(row) {
    return row.index;
};

var editColumnMessages = {
    addCommand: 'Adicionar',
    editCommand: 'Editar',
    deleteCommand: 'Remover',
    commitCommand: 'Salvar',
    cancelCommand: 'Cancelar'
};

var TableEditableWidget = (_temp = _class = function (_Component) {
    _inherits(TableEditableWidget, _Component);

    function TableEditableWidget(props) {
        _classCallCheck(this, TableEditableWidget);

        var _this = _possibleConstructorReturn(this, _Component.call(this, props));

        _initialiseProps.call(_this);

        var value = props.value || [];
        var tableLines = value.map(function (item, index) {
            return item.index = index;
        });

        _this.state = {
            tableLines: tableLines
        };
        return _this;
    }

    TableEditableWidget.prototype.render = function render() {
        var _props = this.props,
            schema = _props.schema,
            label = _props.label;
        var tableLines = this.state.tableLines;


        var columns = this.configureColumns(schema);

        return React.createElement(
            'section',
            null,
            React.createElement(
                FormControl,
                { component: 'fieldset' },
                React.createElement(
                    FormLabel,
                    {
                        component: 'legend',
                        style: { padding: '6px 0 7px' }
                    },
                    label
                )
            ),
            React.createElement(
                FormGroup,
                null,
                React.createElement(
                    Paper,
                    null,
                    React.createElement(
                        Grid,
                        {
                            rows: tableLines,
                            columns: columns,
                            getRowId: getRowId
                        },
                        React.createElement(EditingState, { onCommitChanges: this.commitChanges }),
                        React.createElement(Table, null),
                        React.createElement(TableHeaderRow, null),
                        React.createElement(TableEditRow, null),
                        React.createElement(TableEditColumn, {
                            showAddCommand: !schema.disabled,
                            showEditCommand: !schema.disabled,
                            showDeleteCommand: !schema.disabled,
                            messages: editColumnMessages,
                            width: 180
                        })
                    )
                )
            )
        );
    };

    return TableEditableWidget;
}(Component), _initialiseProps = function _initialiseProps() {
    var _this2 = this;

    this.configureColumns = function (_ref) {
        var elements = _ref.elements;

        return elements.reduce(function (acc, item) {
            var name = item.key,
                title = item.title;

            return [].concat(acc, [{ name: name, title: title }]);
        }, []);
    };

    this.commitChanges = function (_ref2) {
        var added = _ref2.added,
            changed = _ref2.changed,
            deleted = _ref2.deleted;

        var tableLines = _this2.state.tableLines.slice();

        if (changed) {
            Object.keys(changed).map(function (key) {
                return tableLines[key] = changed[key];
            });
        }

        if (deleted) {
            deleted.map(function (index) {
                return tableLines.splice(index, 1);
            });
        }

        if (added) {
            added.map(function (item) {
                return tableLines.push(item);
            });
        }

        tableLines.map(function (item, index) {
            return item.index = index;
        });

        _this2.props.onChange(tableLines);
        _this2.setState({ tableLines: tableLines });
    };
}, _temp);


TableEditableWidget.defaultProps = {
    value: []
};

export default TableEditableWidget;

==> form-dinamico-react-render-0.2.9.tgz: package/es/widgets/mui/TableEditableWidget.js <==
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';

import Paper from 'material-ui/Paper';
import { FormControl, FormGroup, FormLabel } from 'material-ui/Form';

import { EditingState } from '@devexpress/dx-react-grid';
import { Grid, Table, TableEditColumn, TableEditRow, TableHeaderRow } from '@devexpress/dx-react-grid-material-ui';

var getRowId = function getRowId(row) {
    return row.index;
};

var editColumnMessages = {
    addCommand: 'Adicionar',
    editCommand: 'Editar',
    deleteCommand: 'Remover',
    commitCommand: 'Salvar',
    cancelCommand: 'Cancelar'
};

var TableEditableWidget = function (_Component) {
    _inherits(TableEditableWidget, _Component);

    function TableEditableWidget(props) {
        _classCallCheck(this, TableEditableWidget);

        var _this = _possibleConstructorReturn(this, _Component.call(this, props));

        _this.configureColumns = function (_ref) {
            var elements = _ref.elements;

            return elements.reduce(function (acc, item) {
                var name = item.key,
                    title = item.title;

                return [].concat(acc, [{ name: name, title: title }]);
            }, []);
        };

        _this.commitChanges = function (_ref2) {
            var added = _ref2.added,
                changed = _ref2.changed,
                deleted = _ref2.deleted;

            var tableLines = _this.state.tableLines.slice();

            if (changed) {
                Object.keys(changed).map(function (index) {
                    if (changed[index]) {
                        Object.keys(changed[index]).map(function (key) {
                            return tableLines[index][key] = changed[index][key];
                        });
                    }
                });
            }

            if (deleted) {
                deleted.map(function (index) {
                    return tableLines.splice(index, 1);
                });
            }

            if (added) {
                added.map(function (item) {
                    return tableLines.push(item);
                });
            }

            tableLines.map(function (item, index) {
                return item.index = index;
            });

            _this.props.onChange(tableLines);
            _this.setState({ tableLines: tableLines });
        };

        var value = props.value || [];
        value.map(function (item, index) {
            return item.index = index;
        });

        _this.state = {
            tableLines: value
        };
        return _this;
    }

    TableEditableWidget.prototype.render = function render() {
        var _props = this.props,
            schema = _props.schema,
            label = _props.label;
        var tableLines = this.state.tableLines;


        var columns = this.configureColumns(schema);

        return React.createElement(
            'section',
            null,
            React.createElement(
                FormControl,
                { component: 'fieldset' },
                React.createElement(
                    FormLabel,
                    {
                        component: 'legend',
                        style: { padding: '6px 0 7px' }
                    },
                    label
                )
            ),
            React.createElement(
                FormGroup,
                null,
                React.createElement(
                    Paper,
                    null,
                    React.createElement(
                        Grid,
                        {
                            rows: tableLines,
                            columns: columns,
                            getRowId: getRowId
                        },
                        React.createElement(EditingState, { onCommitChanges: this.commitChanges }),
                        React.createElement(Table, null),
                        React.createElement(TableHeaderRow, null),
                        React.createElement(TableEditRow, null),
                        React.createElement(TableEditColumn, {
                            showAddCommand: !schema.disabled,
                            showEditCommand: !schema.disabled,
                            showDeleteCommand: !schema.disabled,
                            messages: editColumnMessages,
                            width: 180
                        })
                    )
                )
            )
        );
    };

    return TableEditableWidget;
}(Component);

TableEditableWidget.defaultProps = {
    value: []
};

export default TableEditableWidget;
